@@ -82,6 +82,7 @@ DiagramScene::DiagramScene(QMenu *itemMenu, QObject *parent)
     myLineWidth = 1;
     myPenStyle = Qt::SolidLine;
     m_undoPos = -1;
+    m_textAlignment = Qt::AlignLeft|Qt::AlignTop;
 
     myRouting=DiagramPathItem::free;
     myGrid=10.0;
@@ -827,7 +828,7 @@ void DiagramScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
         break;
     case MoveItem:
         QGraphicsScene::mouseMoveEvent(mouseEvent);
-        if(mouseEvent->buttons()==Qt::LeftButton){
+        if(mouseEvent->buttons()==Qt::LeftButton && mouseGrabberItem()){
             checkOnGrid();
         }
         break;
