@@ -396,6 +396,21 @@ void MainWindow::flipY()
     transformSelected(QTransform(1,0,0,-1,0,0),m_scene->activeItems());
 }
 
+void MainWindow::scale()
+{
+    if (m_scene->activeItems().isEmpty())
+        return;
+
+    // simple input message box to ask for scale factor
+    bool ok;
+    double scaleFactor = QInputDialog::getDouble(this, tr("Scale"),
+                                                 tr("Scale factor:"), 1.0, 0.01, 100.0, 2, &ok);
+    if (!ok)
+        return;
+
+    transformSelected(QTransform().scale(scaleFactor,scaleFactor),m_scene->activeItems(),true);
+}
+
 void MainWindow::currentFontChanged(const QFont &)
 {
     handleFontChange();
@@ -523,6 +538,11 @@ void MainWindow::itemSelected(QGraphicsItem *item)
 
 void MainWindow::about()
 {
+    /*
+    // provoke crash
+    char *c = nullptr;
+    *c = 'A';
+    */
     QMessageBox::about(this, tr("About QDia"),
                        tr("Version %1\n"
                            "Written by Jan Sundermeyer (C) 2022\n"
@@ -860,6 +880,12 @@ void MainWindow::createActions()
     connect(flipYAction, &QAction::triggered,this, &MainWindow::flipY);
     listOfActions.append(flipYAction);
 
+    scaleAction = new QAction(QIcon(":/images/transform-scale.svg"),
+                              tr("&Scale"), this);
+    //scaleAction->setShortcut(tr("s"));
+    connect(scaleAction, &QAction::triggered,this, &MainWindow::scale);
+    listOfActions.append(scaleAction);
+
     escShortcut = new QShortcut(QKeySequence(Qt::Key_Escape),
                                 this);
     connect(escShortcut,&QShortcut::activated,this,&MainWindow::abort);
@@ -1019,6 +1045,7 @@ void MainWindow::createMenus()
     itemMenu->addAction(rotateLeftAction);
     itemMenu->addAction(flipXAction);
     itemMenu->addAction(flipYAction);
+    itemMenu->addAction(scaleAction);
     itemMenu->addAction(groupAction);
     itemMenu->addAction(ungroupAction);
     itemMenu->addAction(tapAction);
@@ -2166,6 +2193,29 @@ void MainWindow::transformItems(const QTransform transform, QList<QGraphicsItem
 {
     foreach( QGraphicsItem *item, items){
         if(!item) continue;
+        // special treatment for texts
+        if(item->type()==DiagramTextItem::Type){
+            if(transform==QTransform(-1,0,0,1,0,0)){
+                // flipX, text not flipped but anchorpoint moved
+                DiagramTextItem *it=qgraphicsitem_cast<DiagramTextItem*>(item);
+                qreal dx=it->anchorPoint().x()-anchorPoint.x();
+                it->setAnchorPoint(QPointF(it->anchorPoint().x()-2*dx,it->anchorPoint().y()));
+                // move anchor point
+                auto alignment=it->alignment();
+                if(alignment.testFlag(Qt::AlignLeft)){
+                    alignment.setFlag(Qt::AlignRight);
+                    alignment.setFlag(Qt::AlignLeft,false);
+                }else{
+                    if(alignment.testFlag(Qt::AlignRight)){
+                        alignment|=Qt::AlignLeft;
+                        alignment.setFlag(Qt::AlignRight,false);
+                    }
+                }
+                it->setAlignment(alignment);
+                it->updateGeometry();
+                continue;
+            }
+        }
         QTransform trans=item->transform();
         QPointF shift=item->pos()-anchorPoint;
         item->setTransform(trans*QTransform(1,0,0,1,shift.x(),shift.y())*transform*QTransform(1,0,0,1,-shift.x(),-shift.y()),false);
@@ -2231,9 +2281,9 @@ void MainWindow::linePatternChanged()
  * fix flip/rotate when moving/dragging several elements
  * manage user generated elements
  * tap style
- * scale elements ?
  * Align ?
  * import xcircuit/drawio?
  ** read xcircuit lps
  ** show svg
+ ** flipX with shifted text
  */
